@@ -7,7 +7,7 @@ from hestia_earth.validation.utils import _find_linked_node, _value_average, _li
 from .shared import (
     validate_dates, validate_list_dates, validate_date_lt_today, validate_list_min_max,
     validate_list_term_percent, validate_linked_source_privacy, validate_list_dates_length, validate_list_date_lt_today,
-    validate_properties_default_value, validate_list_model, validate_list_model_config, validate_list_dates_format,
+    validate_list_model, validate_list_model_config, validate_list_dates_format,
     validate_list_duplicate_values
 )
 from .input import validate_must_include_id
@@ -15,6 +15,9 @@ from .practice import validate_cropResidueManagement, validate_longFallowPeriod
 from .product import validate_economicValueShare, validate_value as validate_product_value, validate_excreta
 from .data_completeness import validate_dataCompleteness
 from .transformation import validate_previous_transformation, validate_first_transformation
+from .property import (
+    validate_valueType as validate_properties_valueType, validate_default_value as validate_properties_default_value
+)
 
 
 SITE_TYPES_RESTRICTED = [
@@ -174,7 +177,8 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         validate_list_term_percent(cycle, 'emissions'),
         validate_list_dates_length(cycle, 'emissions'),
         validate_list_date_lt_today(cycle, 'emissions', ['startDate', 'endDate']),
-        validate_properties_default_value(cycle, 'emissions', 'properties')
+        validate_properties_default_value(cycle, 'emissions'),
+        validate_properties_valueType(cycle, 'emissions')
     ] if len(cycle.get('emissions', [])) > 0 else []) + flatten([
         validate_list_dates(cycle, 'inputs'),
         validate_list_dates_format(cycle, 'inputs'),
@@ -182,7 +186,8 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         validate_list_date_lt_today(cycle, 'inputs', ['startDate', 'endDate']),
         validate_list_min_max(cycle, 'inputs'),
         validate_list_term_percent(cycle, 'inputs'),
-        validate_properties_default_value(cycle, 'inputs', 'properties'),
+        validate_properties_default_value(cycle, 'inputs'),
+        validate_properties_valueType(cycle, 'inputs'),
         validate_must_include_id(cycle['inputs'])
     ] if len(cycle.get('inputs', [])) > 0 else []) + flatten([
         validate_list_dates(cycle, 'products'),
@@ -194,7 +199,8 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         validate_economicValueShare(cycle.get('products')),
         validate_sum_aboveGroundCropResidue(cycle.get('products')),
         validate_product_value(cycle.get('products')),
-        validate_properties_default_value(cycle, 'products', 'properties'),
+        validate_properties_default_value(cycle, 'products'),
+        validate_properties_valueType(cycle, 'products'),
         validate_crop_residue_completeness(cycle, site) if 'dataCompleteness' in cycle and site else True,
         validate_list_model_config(cycle, 'products', PRODUCTS_MODEL_CONFIG),
         validate_excreta(cycle, 'products')
@@ -206,7 +212,8 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         validate_list_term_percent(cycle, 'practices'),
         validate_cropResidueManagement(cycle.get('practices')),
         validate_longFallowPeriod(cycle.get('practices')),
-        validate_properties_default_value(cycle, 'practices', 'properties'),
+        validate_properties_default_value(cycle, 'practices'),
+        validate_properties_valueType(cycle, 'practices'),
         validate_list_duplicate_values(cycle, 'practices', 'term.termType', TermTermType.EXCRETAMANAGEMENT.value)
     ] if len(cycle.get('practices', [])) > 0 else []) + flatten([
         validate_functionalUnit(cycle, site)
