@@ -5,6 +5,7 @@ from .shared import (
     validate_list_term_percent, validate_linked_source_privacy, validate_date_lt_today,
     validate_list_model
 )
+from .indicator import validate_characterisedIndicator_model
 
 
 def validate_impact_assessment(impact_assessment: dict, node_map: dict = {}):
@@ -36,11 +37,13 @@ def validate_impact_assessment(impact_assessment: dict, node_map: dict = {}):
         validate_list_term_percent(impact_assessment, 'impacts'),
         validate_list_duplicates(impact_assessment, 'impacts', [
             'term.@id'
-        ])
+        ]),
+        validate_characterisedIndicator_model(impact_assessment, 'impacts')
     ] if 'impacts' in impact_assessment else []) + flatten([
         validate_list_min_max(impact_assessment, 'emissionsResourceUse'),
         validate_list_term_percent(impact_assessment, 'emissionsResourceUse'),
         validate_list_duplicates(impact_assessment, 'emissionsResourceUse', [
             'term.@id'
-        ])
+        ]),
+        validate_characterisedIndicator_model(impact_assessment, 'emissionsResourceUse')
     ] if 'emissionsResourceUse' in impact_assessment else [])
