@@ -6,14 +6,17 @@ from .shared import (
     validate_dates, validate_list_dates, validate_list_dates_format, validate_list_min_max,
     validate_region_in_country, validate_country, validate_is_region, validate_coordinates, need_validate_coordinates,
     validate_area, need_validate_area, validate_list_term_percent, validate_linked_source_privacy,
-    validate_list_date_lt_today, validate_date_lt_today, validate_properties_default_value
+    validate_list_date_lt_today, validate_date_lt_today
 )
 from .infrastructure import validate_lifespan
 from .measurement import (
     validate_soilTexture, validate_depths, validate_value_min_max, validate_term_unique,
-    validate_require_startDate_endDate, validate_with_models
+    validate_require_startDate_endDate, validate_with_models, validate_value_length
 )
 from .practice import validate_cropResidueManagement, validate_longFallowPeriod
+from .property import (
+    validate_valueType as validate_properties_valueType, validate_default_value as validate_properties_default_value
+)
 
 
 INLAND_TYPES = [
@@ -107,9 +110,11 @@ def validate_site(site: dict, node_map: dict = {}):
         validate_depths(site.get('measurements')),
         validate_value_min_max(site.get('measurements')),
         validate_term_unique(site.get('measurements')),
-        validate_properties_default_value(site, 'measurements', 'properties'),
+        validate_properties_default_value(site, 'measurements'),
+        validate_properties_valueType(site, 'measurements'),
         validate_require_startDate_endDate(site.get('measurements')),
-        validate_with_models(site, 'measurements')
+        validate_with_models(site, 'measurements'),
+        validate_value_length(site, 'measurements')
     ] if 'measurements' in site else []) + flatten([
         validate_list_dates(site, 'infrastructure'),
         validate_list_dates_format(site, 'infrastructure'),
@@ -123,5 +128,6 @@ def validate_site(site: dict, node_map: dict = {}):
         validate_list_term_percent(site, 'practices'),
         validate_cropResidueManagement(site.get('practices')),
         validate_longFallowPeriod(site.get('practices')),
-        validate_properties_default_value(site, 'practices', 'properties')
+        validate_properties_default_value(site, 'practices'),
+        validate_properties_valueType(site, 'practices')
     ] if 'practices' in site else [])
