@@ -23,5 +23,5 @@ def test_validate_must_include_id_invalid():
     assert validate_must_include_id(data.get('nodes')) == {
         'level': 'error',
         'dataPath': '.inputs[0]',
-        'message': 'should add missing inputs: potassiumNitrateAsK2O'
+        'message': 'should add missing inputs: potassiumNitrateKgK2O'
     }
