@@ -1,43 +1,93 @@
+from unittest.mock import patch
 import json
 
 from tests.utils import fixtures_path
 from hestia_earth.validation.validators.measurement import (
     validate_soilTexture, validate_depths, validate_value_min_max, validate_term_unique,
-    validate_require_startDate_endDate, validate_with_models
+    validate_require_startDate_endDate, validate_with_models, validate_value_length
 )
 
+class_path = 'hestia_earth.validation.validators.measurement'
+
 
 def test_validate_soilTexture_invalid():
     # 90% on same depthUpper / depthLower
     with open(f"{fixtures_path}/measurement/soilTexture/low-value.json") as f:
         data = json.load(f)
-    assert validate_soilTexture(data.get('nodes')) == {
-        'level': 'error',
-        'dataPath': '.measurements',
-        'message': 'sum not equal to 100% for sandContent, siltContent, clayContent'
-    }
+    assert validate_soilTexture(data.get('nodes')) == [
+        {
+            'level': 'error',
+            'dataPath': '.measurements[0]',
+            'message': 'sum not equal to 100% for sandContent, siltContent, clayContent'
+        },
+        {
+            'level': 'error',
+            'dataPath': '.measurements[1]',
+            'message': 'sum not equal to 100% for sandContent, siltContent, clayContent'
+        },
+        {
+            'level': 'error',
+            'dataPath': '.measurements[2]',
+            'message': 'sum not equal to 100% for sandContent, siltContent, clayContent'
+        }
+    ]
 
     # remove all depthUpper / depthLower
     with open(f"{fixtures_path}/measurement/soilTexture/no-depth-high-value.json") as f:
         data = json.load(f)
-    assert validate_soilTexture(data.get('nodes')) == {
-        'level': 'error',
-        'dataPath': '.measurements',
-        'message': 'sum not equal to 100% for sandContent, siltContent, clayContent'
-    }
+    assert validate_soilTexture(data.get('nodes')) == [
+        {
+            'level': 'error',
+            'dataPath': '.measurements[0]',
+            'message': 'sum not equal to 100% for sandContent, siltContent, clayContent'
+        },
+        {
+            'level': 'error',
+            'dataPath': '.measurements[1]',
+            'message': 'sum not equal to 100% for sandContent, siltContent, clayContent'
+        },
+        {
+            'level': 'error',
+            'dataPath': '.measurements[2]',
+            'message': 'sum not equal to 100% for sandContent, siltContent, clayContent'
+        },
+        {
+            'level': 'error',
+            'dataPath': '.measurements[3]',
+            'message': 'sum not equal to 100% for sandContent, siltContent, clayContent'
+        }
+    ]
 
-    # invalid percent
+
+def test_validate_soilTexture_invalid_percent():
     with open(f"{fixtures_path}/measurement/soilTexture/percent-invalid.json") as f:
         data = json.load(f)
-    assert validate_soilTexture(data.get('nodes')) == {
-        'level': 'error',
-        'dataPath': '.measurements',
-        'message': 'is outside the allowed range',
-        'params': {
-            'term': {'@id': 'sandContent', '@type': 'Term'},
-            'range': {'min': 86, 'max': 100}
+    assert validate_soilTexture(data.get('nodes')) == [
+        {
+            'level': 'error',
+            'dataPath': '.measurements[0].value',
+            'message': 'is outside the allowed range',
+            'params': {
+                'range': {'min': 86, 'max': 100}
+            }
+        },
+        {
+            'level': 'error',
+            'dataPath': '.measurements[4].value',
+            'message': 'is outside the allowed range',
+            'params': {
+                'range': {'min': 20, 'max': 45}
+            }
+        },
+        {
+            'level': 'error',
+            'dataPath': '.measurements[6].value',
+            'message': 'is outside the allowed range',
+            'params': {
+                'range': {'min': 27, 'max': 40}
+            }
         }
-    }
+    ]
 
 
 def test_validate_soilTexture_valid():
@@ -165,7 +215,8 @@ def test_validate_require_startDate_endDate_invalid():
     }]
 
 
-def test_validate_with_models_valid():
+@patch(f"{class_path}.fetch_data", return_value={'mean': 1})
+def test_validate_with_models_valid(*args):
     # no measurements should be valid
     assert validate_with_models({}, 'measurements') is True
 
@@ -174,7 +225,8 @@ def test_validate_with_models_valid():
     assert validate_with_models(data, 'measurements') is True
 
 
-def test_validate_with_models_invalid():
+@patch(f"{class_path}.fetch_data", return_value={'mean': 1})
+def test_validate_with_models_warning(*args):
     with open(f"{fixtures_path}/measurement/models/warning.json") as f:
         data = json.load(f)
     assert validate_with_models(data, 'measurements') == {
@@ -183,8 +235,8 @@ def test_validate_with_models_invalid():
         'message': 'the measurement provided might be in error',
         'params': {
             'current': 500,
-            'expected': 846.5314116328955,
-            'delta': 40.94,
+            'expected': 1000,
+            'delta': 50,
             'term': {
                 '@id': 'rainfallAnnual',
                 '@type': 'Term',
@@ -192,3 +244,41 @@ def test_validate_with_models_invalid():
             }
         }
     }
+
+    # with no value warning must be on blank node
+    with open(f"{fixtures_path}/measurement/models/warning-no-value.json") as f:
+        data = json.load(f)
+    assert validate_with_models(data, 'measurements') == {
+        'level': 'warning',
+        'dataPath': '.measurements[0]',
+        'message': 'the measurement provided might be in error',
+        'params': {
+            'current': 0,
+            'expected': 1000,
+            'delta': 100,
+            'term': {
+                '@id': 'rainfallAnnual',
+                '@type': 'Term',
+                'name': 'Rainfall annual'
+            }
+        }
+    }
+
+
+def test_validate_value_length_valid():
+    # no measurements should be valid
+    assert validate_value_length({}, 'measurements') is True
+
+    with open(f"{fixtures_path}/measurement/value-length/valid.json") as f:
+        data = json.load(f)
+    assert validate_value_length(data, 'measurements') is True
+
+
+def test_validate_value_length_invalid():
+    with open(f"{fixtures_path}/measurement/value-length/invalid.json") as f:
+        data = json.load(f)
+    assert validate_value_length(data, 'measurements') == {
+        'level': 'error',
+        'dataPath': '.measurements[1].value',
+        'message': 'must not contain more than 1 value'
+    }
