@@ -7,7 +7,7 @@ from hestia_earth.validation.validators.organisation import validate_organisatio
 def test_validate_valid():
     with open(f"{fixtures_path}/organisation/valid.json") as f:
         node = json.load(f)
-    assert validate_organisation(node) == [True] * 7
+    assert validate_organisation(node) == [True] * 8
 
 
 def test_validate_organisation_dates_valid():
@@ -15,7 +15,7 @@ def test_validate_organisation_dates_valid():
         'startDate': '2020-01-01',
         'endDate': '2020-01-02'
     }
-    assert validate_organisation_dates(organisation)
+    assert validate_organisation_dates(organisation) is True
 
 
 def test_validate_organisation_dates_invalid():
