@@ -40,7 +40,7 @@ def test_validate_value_warning():
         data = json.load(f)
     assert validate_value(data.get('nodes')) == {
         'level': 'warning',
-        'dataPath': '.products[1].value',
+        'dataPath': '.products[1]',
         'message': 'may not be 0'
     }
 
